#!/usr/bin/python
#
# ESA (C) 2000-2021 
#
# This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
#
#    SAS is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    SAS is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with SAS.  If not, see <http://www.gnu.org/licenses/>.


import pysas.pysasplot_utils.pysasplot_utils as pysasplt
import numpy as np
from astropy.io import fits
from astropy.table import Table
import matplotlib.pyplot as plt
import os

##############################

def test_2dplot():
    pysasplt.simple_2d_plot('RATE:TIME', 'RATE:RATE', x_data_errors = '', y_data_errors = '', plot_title = 'example2', x_label = 'x', y_label = 'y', fits_file = 'example.fits', fits_info = True, \
        add_text = '', scale = '', outformat = 'png')
    assert True


def test_1d_hist():
    pysasplt.simple_1d_hist(y_data = ['RATE:RATE', np.random.rand(5000)*10], x_label = 'x', y_label = 'y', add_text = '', y_data_errors = '', scale = '', nbins = 40, sharebins = True, \
        fits_file = 'example.fits', fits_info = True, plot_title = 'example_1d', outformat = 'png')
    assert True


def test_table():
    a = fits.open('example.fits')
    t = Table(a[1].data)
    n_rows = len(t)
    pysasplt.simple_2d_plot('TIME', 'RATE', x_data_errors = '', y_data_errors = 'ERROR', plot_title = 'example for tables', x_label = 'x', y_label = 'y', fits_file = t, fits_info = True, \
        add_text = 'This is a simple example.', scale = '', points = 512, outformat = 'png')
    a.close()
    assert True


def test_get_time_deltas():
    a = fits.open('example.fits')
    DTin, DTout = pysasplt.get_time_deltas('example.fits', 1, 10)
    a.close()
    assert DTin == 100 and DTout == 2360


def test_TSrebin():
    a = fits.open('example.fits')
    test_data = a[1].data
    table = pysasplt.TSrebin(test_data, 1,1)
    a.close()
    assert len(table) == test_data.size


def test_load_pickled_fig():
   figs = pysasplt.load_figures(['test.fig.pickle'])
   fig = figs[0]
   print(type(fig))
   assert True


def test_merge_pdf():
    pdf_list = ('pdf1.pdf', 'pdf2.pdf')
    status = pysasplt.merge_pdf(pdf_list, 'result.pdf')
    os.remove('result.pdf')
    assert status == 1
